@@ -137,7 +137,6 @@ sub BUILD {
 
     if (logged_in_user) {
         $roles = user_roles;
-        push @$roles, 'authenticated';
     }
 
     while ( my $record = $rset->next ) {
@@ -146,10 +145,12 @@ sub BUILD {
           {
             id            => $record->cart_products_id,
             sku           => $record->sku,
+            canonical_sku => $record->product->canonical_sku,
             name          => $record->product->name,
             quantity      => $record->quantity,
             price         => $record->product->price,
             uri           => $record->product->uri,
+            weight        => $record->product->weight,
             selling_price => $record->product->selling_price(
                 { quantity => $record->quantity, roles => $roles }
             ),
@@ -210,10 +211,12 @@ around 'add' => sub {
           unless defined $result;
 
         my $product = {
-            name     => $result->name,
-            price    => $result->price,
-            sku      => $result->sku,
-            uri      => $result->uri,
+            name          => $result->name,
+            price         => $result->price,
+            sku           => $result->sku,
+            canonical_sku => $result->canonical_sku,
+            uri           => $result->uri,
+            weight        => $result->weight,
         };
         $product->{quantity} = $arg->{quantity}
           if defined( $arg->{quantity} );
@@ -256,7 +259,7 @@ around 'add' => sub {
 
         my $query = { quantity => $ret->quantity };
         if ( logged_in_user ) {
-            $query->{roles} = [ user_roles, 'authenticated' ];
+            $query->{roles} = [ user_roles ];
         }
         $ret->selling_price( $cart_product->product->selling_price($query) );
 
